@@ -18,15 +18,15 @@ module Codec.Binary.Yenc
 
 import Data.Word
 
-_criticals_in = [0xd6, 0xe0, 0xe3, 0x13]
+_criticalsIn = [0xd6, 0xe0, 0xe3, 0x13]
 _equal = 0x3d
 
 -- {{{1 encode
 -- | Encode data.
 encode :: [Word8]
     -> [Word8]
-encode (d:ds)
-    | d `elem` _criticals_in = _equal : d + 106 : encode ds
+encode (d : ds)
+    | d `elem` _criticalsIn = _equal : d + 106 : encode ds
     | otherwise = d + 42 : encode ds
 encode _ = []
 
@@ -34,8 +34,8 @@ encode _ = []
 -- | Decode data (lazy).
 decode' :: [Word8]
     -> [Maybe Word8]
-decode' (0x3d:d:ds) = Just (d + 150) : decode' ds
-decode' (d:ds) = Just (d + 214) : decode' ds
+decode' (0x3d : d : ds) = Just (d + 150) : decode' ds
+decode' (d : ds) = Just (d + 214) : decode' ds
 decode' _ = []
 
 -- | Decode data (strict).
@@ -53,8 +53,8 @@ chop n ws = let
         _n = max n 1
         (p1, p2) = splitAt _n ws
     in
-        if (last p1 == _equal)
-            then (p1 ++ (take 1 p2)) : chop _n (drop 1 p2)
+        if last p1 == _equal
+            then (p1 ++ take 1 p2) : chop _n (drop 1 p2)
             else p1 : chop _n p2
 
 -- {{{1 unchop
